California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 064- MARIJUANA LEGALIZATION. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1381808 | YES ON 64, CALIFORNIANS TO CONTROL, REGULATE AND TAX ADULT USE OF MARIJUANA WHILE PROTECTING CHILDREN, SPONSORED BY BUSINESS, PHYSICIANS, ENVIRONMENTAL AND SOCIAL-JUSTICE ADVOCATE ORGANIZATIONS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1387789 | SAM ACTION, INC., A COMMITTEE AGAINST PROPOSITION 64 WITH HELP FROM CITIZENS (NONPROFIT 501 (C)(4)) | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1382568 | PUBLIC AND MENTAL HEALTH ADVOCATES AGAINST 64, SPONSORED AND MAJOR FUNDING BY SAM ACTION, INC. AND CALIFORNIA PUBLIC SAFETY INSTITUTE | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1371855 | MARIJUANA POLICY PROJECT OF CALIFORNIA, YES ON 64 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1385745 | FUND FOR POLICY REFORM (NONPROFIT 501(C)(4)) | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1385506 | DRUG POLICY ACTION - NON PROFIT 501C4, YES ON PROP. 64 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1390962 | MOMS STRONG AGAINST PROP 64 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1343793 | CALIFORNIANS FOR RESPONSIBLE MARIJUANA REFORM, SPONSORED BY DRUG POLICY ACTION, YES ON PROP. 64 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1386560 | ADULT USE CAMPAIGN FOR PROPOSITION 64; THE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1382525 | NEW APPROACH PAC (MPO) | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1376077 | CALIFORNIANS FOR SENSIBLE REFORM, SPONSORED BY GHOST MANAGEMENT GROUP, LLC DBA WEEDMAPS | SUPPORT